# nlp-kan

This software is provided as-is without any warranties. You are free to use, modify, and distribute this code for personal and non-commercial purposes. However, please provide appropriate attribution to the original author.
